Stan Math Library: stan/math/prim/scal/fun/fill.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

fill.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_FILL_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_FILL_HPP
3
4 namespace stan {
5 namespace math {
6
17 template <typename T, typename S>
18 void fill(T& x, const S& y) {
19 x = y;
20 }
21
22 }
23 }
24 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::fill
void fill(std::vector< T > &x, const S &y)
Fill the specified container with the specified value.
Definition: fill.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.